import UIAbility from "@ohos:app.ability.UIAbility";
import type { Context } from "@ohos:abilityAccessCtrl";
import type AbilityConstant from "@ohos:app.ability.AbilityConstant";
import type Want from "@ohos:app.ability.Want";
import window from "@ohos:window";
import hilog from "@ohos:hilog";
import type { BusinessError } from "@ohos:base";
const DOMAIN_NUMBER: number = 0xFF00;
const TAG: string = '[EventAbility]';
export default class EntryAbility extends UIAbility {
    windowStage: window.WindowStage | undefined = undefined;
    onCreate(want: Want, launchParam: AbilityConstant.LaunchParam): void {
        let context = this.context;
        // console.info(JSON.stringify(context))
        console.info('onCreate');
        // 获取eventHub
        let eventhub = this.context.eventHub;
        // 执行订阅操作
        eventhub.on('event1', this.eventFunc);
        eventhub.on('event1', (data: string) => {
        });
        hilog.info(DOMAIN_NUMBER, TAG, '%{public}s', 'Ability onCreate');
    }
    onWindowStageCreate(windowStage: window.WindowStage): void {
        this.windowStage = windowStage;
        // 设置WindowStage事件订阅（获焦/失焦、可见/不可见）
        try {
            windowStage.on('windowStageEvent', (data) => {
                let stageEventType: window.WindowStageEventType = data;
                switch (stageEventType) {
                    case window.WindowStageEventType.SHOWN: // 切到前台
                        console.info('UIAbility windowStage foreground.');
                        break;
                    case window.WindowStageEventType.ACTIVE: // 获焦状态
                        console.info('UIAbility windowStage active.');
                        break;
                    case window.WindowStageEventType.INACTIVE: // 失焦状态
                        console.info('UIAbility windowStage inactive.');
                        break;
                    case window.WindowStageEventType.HIDDEN: // 切到后台
                        console.info('UIAbility windowStage background.');
                        break;
                    default:
                        break;
                }
            });
        }
        catch (exception) {
            console.error('Failed to enable the listener for window stage event changes. Cause:' + JSON.stringify(exception));
        }
        // 设置UI加载
        windowStage.loadContent('pages/Index', (err, data) => {
            console.info('loadContent');
        });
    }
    onWindowStageDestroy(): void {
        // 释放UI资源
        // 例如在onWindowStageDestroy()中注销获焦/失焦等WindowStage事件
        try {
            if (this.windowStage) {
                this.windowStage.off('windowStageEvent');
            }
        }
        catch (err) {
            let code = (err as BusinessError).code;
            let message = (err as BusinessError).message;
            hilog.error(DOMAIN_NUMBER, TAG, `Failed to disable the listener for windowStageEvent. Code is ${code}, message is ${message}`);
        }
    }
    onWindowStageWillDestroy(windowStage: window.WindowStage) {
        // 释放通过windowStage对象获取等资源
        console.info('UIAbility onWindowStageWillDestroy');
    }
    onForeground(): void {
        console.info('UIAbility onForeground');
    }
    onBackground(): void {
        console.info('UIAbility onBackground');
    }
    onNewWant(want: Want, launchParam: AbilityConstant.LaunchParam): void {
        console.info('UIAbility onNewWant');
    }
    eventFunc(argOne: Context, argTwo: Context): void {
        hilog.info(DOMAIN_NUMBER, TAG, '1. ' + `${argOne}, ${argTwo}`);
        return;
    }
    onDestroy(): void | Promise<void> {
        this.context.eventHub.off('event1');
        console.info('UIAbility onDestroy');
    }
}
